Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
Functions ¶
func DecryptSecrets ¶
DecryptSecrets decrypts the secrets file and returns the plaintext content.
func EncryptSecrets ¶
EncryptSecrets encrypts the given secrets string using age encryption and saves to the specified path.
func EnsureKeyExists ¶
EnsureKeyExists generates a new encryption key if one doesn't exist at the specified directory.
func GenerateKey ¶
GenerateKey generates a new X25519 encryption key and saves it to the specified path.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.